@@ -85,7 +85,7 @@ apply_changes (GsAppFolderDialog *dialog)
 	for (l = priv->apps; l; l = l->next) {
 		GsApp *app = l->data;
 		gs_folders_set_app_folder (priv->folders,
-					   gs_app_get_id_full (app),
+					   gs_app_get_id (app),
 					   gs_app_get_categories (app),
 					   folder);
 	}
@@ -157,7 +157,7 @@ gs_app_folder_dialog_class_init (GsAppFolderDialogClass *klass)
 
 	widget_class->destroy = gs_app_folder_dialog_destroy;
 
-	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/software/app-folder-dialog.ui");
+	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/app-folder-dialog.ui");
 
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppFolderDialog, header);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppFolderDialog, cancel_button);
