@@ -44,6 +44,7 @@ struct GsPluginLoaderPrivate
 	GSettings		*settings;
 
 	gchar			**compatible_projects;
+	gint			 scale;
 
 	GList			*queued_installs;
 	gboolean		 online; 
@@ -307,13 +308,13 @@ gs_plugin_loader_run_refine (GsPluginLoader *plugin_loader,
 		}
 	}
 
+	/* dedupe applications we already know about */
+	gs_plugin_loader_list_dedupe (plugin_loader, *list);
+out:
 	/* now emit all the changed signals */
 	for (l = freeze_list; l != NULL; l = l->next)
 		g_object_thaw_notify (G_OBJECT (l->data));
 
-	/* dedupe applications we already know about */
-	gs_plugin_loader_list_dedupe (plugin_loader, *list);
-out:
 	gs_plugin_list_free (addons_list);
 	gs_plugin_list_free (related_list);
 	gs_plugin_list_free (freeze_list);
@@ -670,6 +671,13 @@ gs_plugin_loader_filter_qt_for_gtk (GsApp *app, gpointer user_data)
 			 gs_plugin_loader_get_app_str (app));
 		return FALSE;
 	}
+
+	/* hide the KDE version in preference to the Qt one */
+	if (g_strcmp0 (gs_app_get_id (app), "kid3.desktop") == 0) {
+		g_debug ("removing KDE version of %s",
+			 gs_plugin_loader_get_app_str (app));
+		return FALSE;
+	}
 	return TRUE;
 }
 
@@ -1049,6 +1057,7 @@ gs_plugin_loader_get_updates_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_updates_thread_cb);
 	g_object_unref (task);
 }
@@ -1146,6 +1155,7 @@ gs_plugin_loader_get_sources_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_sources_thread_cb);
 	g_object_unref (task);
 }
@@ -1252,6 +1262,7 @@ gs_plugin_loader_get_installed_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_installed_thread_cb);
 	g_object_unref (task);
 }
@@ -1305,6 +1316,7 @@ gs_plugin_loader_get_popular_thread_cb (GTask *task,
 	/* filter package list */
 	gs_plugin_list_filter (&state->list, gs_plugin_loader_app_is_valid, NULL);
 	gs_plugin_list_filter (&state->list, gs_plugin_loader_app_is_non_installed, NULL);
+	gs_plugin_list_filter (&state->list, gs_plugin_loader_filter_qt_for_gtk, NULL);
 	if (state->list == NULL) {
 		g_task_return_new_error (task,
 		                         GS_PLUGIN_LOADER_ERROR,
@@ -1349,6 +1361,7 @@ gs_plugin_loader_get_popular_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_popular_thread_cb);
 	g_object_unref (task);
 }
@@ -1471,6 +1484,7 @@ gs_plugin_loader_get_featured_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_featured_thread_cb);
 	g_object_unref (task);
 }
@@ -1529,7 +1543,7 @@ gs_plugin_loader_convert_unavailable_app (GsApp *app, const gchar *search)
 	gs_app_set_kind (app, GS_APP_KIND_MISSING);
 	gs_app_set_size (app, GS_APP_SIZE_MISSING);
 	gs_app_set_icon (app, "dialog-question-symbolic");
-	gs_app_load_icon (app, NULL);
+	gs_app_load_icon (app, 1, NULL);
 	g_string_free (tmp, TRUE);
 	return TRUE;
 }
@@ -1574,7 +1588,7 @@ gs_plugin_loader_search_thread_cb (GTask *task,
 {
 	const gchar *function_name = "gs_plugin_add_search";
 	gboolean ret = TRUE;
-	gchar *profile_id;
+	gchar *profile_id = NULL;
 	GError *error = NULL;
 	GsPluginLoaderAsyncState *state = (GsPluginLoaderAsyncState *) task_data;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
@@ -1607,7 +1621,7 @@ gs_plugin_loader_search_thread_cb (GTask *task,
 		}
 		gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_FINISHED);
 		gs_profile_stop (plugin_loader->priv->profile, profile_id);
-		g_free (profile_id);
+		g_clear_pointer (&profile_id, g_free);
 	}
 
 	/* dedupe applications we already know about */
@@ -1649,6 +1663,10 @@ gs_plugin_loader_search_thread_cb (GTask *task,
 	/* success */
 	g_task_return_pointer (task, gs_plugin_list_copy (state->list), (GDestroyNotify) gs_plugin_list_free);
 out:
+	if (profile_id != NULL) {
+		gs_profile_stop (plugin_loader->priv->profile, profile_id);
+		g_free (profile_id);
+	}
 	g_strfreev (values);
 }
 
@@ -1695,6 +1713,7 @@ gs_plugin_loader_search_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_search_thread_cb);
 	g_object_unref (task);
 }
@@ -1740,7 +1759,7 @@ gs_plugin_loader_get_categories_thread_cb (GTask *task,
 {
 	const gchar *function_name = "gs_plugin_add_categories";
 	gboolean ret = TRUE;
-	gchar *profile_id;
+	gchar *profile_id = NULL;
 	GError *error = NULL;
 	GsPluginLoaderAsyncState *state = (GsPluginLoaderAsyncState *) task_data;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
@@ -1772,7 +1791,7 @@ gs_plugin_loader_get_categories_thread_cb (GTask *task,
 		}
 		gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_FINISHED);
 		gs_profile_stop (plugin_loader->priv->profile, profile_id);
-		g_free (profile_id);
+		g_clear_pointer (&profile_id, g_free);
 	}
 
 	/* sort by name */
@@ -1792,6 +1811,10 @@ gs_plugin_loader_get_categories_thread_cb (GTask *task,
 	/* success */
 	g_task_return_pointer (task, gs_plugin_list_copy (state->list), (GDestroyNotify) gs_plugin_list_free);
 out:
+	if (profile_id != NULL) {
+		gs_profile_stop (plugin_loader->priv->profile, profile_id);
+		g_free (profile_id);
+	}
 	return;
 }
 
@@ -1821,6 +1844,7 @@ gs_plugin_loader_get_categories_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_categories_thread_cb);
 	g_object_unref (task);
 }
@@ -1856,7 +1880,7 @@ gs_plugin_loader_get_category_apps_thread_cb (GTask *task,
 {
 	const gchar *function_name = "gs_plugin_add_category_apps";
 	gboolean ret = TRUE;
-	gchar *profile_id;
+	gchar *profile_id = NULL;
 	GError *error = NULL;
 	GsPluginLoaderAsyncState *state = (GsPluginLoaderAsyncState *) task_data;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
@@ -1887,7 +1911,7 @@ gs_plugin_loader_get_category_apps_thread_cb (GTask *task,
 		}
 		gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_FINISHED);
 		gs_profile_stop (plugin_loader->priv->profile, profile_id);
-		g_free (profile_id);
+		g_clear_pointer (&profile_id, g_free);
 	}
 
 	/* dedupe applications we already know about */
@@ -1924,6 +1948,10 @@ gs_plugin_loader_get_category_apps_thread_cb (GTask *task,
 	/* success */
 	g_task_return_pointer (task, gs_plugin_list_copy (state->list), (GDestroyNotify) gs_plugin_list_free);
 out:
+	if (profile_id != NULL) {
+		gs_profile_stop (plugin_loader->priv->profile, profile_id);
+		g_free (profile_id);
+	}
 	return;
 }
 
@@ -1970,6 +1998,7 @@ gs_plugin_loader_get_category_apps_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_get_category_apps_thread_cb);
 	g_object_unref (task);
 }
@@ -2056,6 +2085,7 @@ gs_plugin_loader_app_refine_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_app_refine_thread_cb);
 	g_object_unref (task);
 }
@@ -2377,6 +2407,7 @@ gs_plugin_loader_app_action_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_app_action_thread_cb);
 	g_object_unref (task);
 }
@@ -2589,6 +2620,7 @@ gs_plugin_loader_open_plugin (GsPluginLoader *plugin_loader,
 	plugin->updates_changed_fn = gs_plugin_loader_updates_changed_cb;
 	plugin->updates_changed_user_data = plugin_loader;
 	plugin->profile = g_object_ref (plugin_loader->priv->profile);
+	plugin->scale = gs_plugin_loader_get_scale (plugin_loader);
 	g_debug ("opened plugin %s: %s", filename, plugin->name);
 
 	/* add to array */
@@ -2597,6 +2629,32 @@ out:
 	return plugin;
 }
 
+/**
+ * gs_plugin_loader_set_scale:
+ */
+void
+gs_plugin_loader_set_scale (GsPluginLoader *plugin_loader, gint scale)
+{
+	GsPlugin *plugin;
+	guint i;
+
+	/* save globally, and update each plugin */
+	plugin_loader->priv->scale = scale;
+	for (i = 0; i < plugin_loader->priv->plugins->len; i++) {
+		plugin = g_ptr_array_index (plugin_loader->priv->plugins, i);
+		plugin->scale = scale;
+	}
+}
+
+/**
+ * gs_plugin_loader_get_scale:
+ */
+gint
+gs_plugin_loader_get_scale (GsPluginLoader *plugin_loader)
+{
+	return plugin_loader->priv->scale;
+}
+
 /**
  * gs_plugin_loader_set_location:
  */
@@ -2828,6 +2886,7 @@ gs_plugin_loader_init (GsPluginLoader *plugin_loader)
 	guint i;
 
 	plugin_loader->priv = gs_plugin_loader_get_instance_private (plugin_loader);
+	plugin_loader->priv->scale = 1;
 	plugin_loader->priv->plugins = g_ptr_array_new_with_free_func ((GDestroyNotify) gs_plugin_loader_plugin_free);
 	plugin_loader->priv->status_last = GS_PLUGIN_STATUS_LAST;
 	plugin_loader->priv->pending_apps = g_ptr_array_new_with_free_func ((GFreeFunc) g_object_unref);
@@ -3130,6 +3189,7 @@ gs_plugin_loader_refresh_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_refresh_thread_cb);
 	g_object_unref (task);
 }
@@ -3165,7 +3225,7 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
 {
 	const gchar *function_name = "gs_plugin_filename_to_app";
 	gboolean ret = TRUE;
-	gchar *profile_id;
+	gchar *profile_id = NULL;
 	GError *error = NULL;
 	GsPluginLoaderAsyncState *state = (GsPluginLoaderAsyncState *) task_data;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
@@ -3196,7 +3256,7 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
 		}
 		gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_FINISHED);
 		gs_profile_stop (plugin_loader->priv->profile, profile_id);
-		g_free (profile_id);
+		g_clear_pointer (&profile_id, g_free);
 	}
 
 	/* dedupe applications we already know about */
@@ -3235,6 +3295,10 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
 	}
 	g_task_return_pointer (task, g_object_ref (state->list->data), (GDestroyNotify) g_object_unref);
 out:
+	if (profile_id != NULL) {
+		gs_profile_stop (plugin_loader->priv->profile, profile_id);
+		g_free (profile_id);
+	}
 	return;
 }
 
@@ -3272,6 +3336,7 @@ gs_plugin_loader_filename_to_app_async (GsPluginLoader *plugin_loader,
 	/* run in a thread */
 	task = g_task_new (plugin_loader, cancellable, callback, user_data);
 	g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
+	g_task_set_return_on_cancel (task, TRUE);
 	g_task_run_in_thread (task, gs_plugin_loader_filename_to_app_thread_cb);
 	g_object_unref (task);
 }
