@@ -163,6 +163,9 @@ gboolean	 gs_plugin_loader_set_enabled		(GsPluginLoader	*plugin_loader,
 							 gboolean	 enabled);
 void		 gs_plugin_loader_set_location		(GsPluginLoader	*plugin_loader,
 							 const gchar	*location);
+gint		 gs_plugin_loader_get_scale		(GsPluginLoader	*plugin_loader);
+void		 gs_plugin_loader_set_scale		(GsPluginLoader	*plugin_loader,
+							 gint		 scale);
 void		 gs_plugin_loader_app_refine_async	(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
 							 GsPluginRefineFlags flags,
