@@ -515,7 +515,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	GError *error = NULL;
 	GPtrArray *history;
 	GdkPixbuf *pixbuf = NULL;
-	GList *addons, *l;
+	GList *addons;
 	GsShellDetailsPrivate *priv = shell_details->priv;
 	GtkWidget *widget;
 	const gchar *tmp;
@@ -566,7 +566,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 			pixbuf = gs_pixbuf_load ("application-x-executable", NULL, 96, NULL);
 	}
 	if (pixbuf != NULL) {
-		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->application_details_icon), pixbuf);
+		gs_image_set_from_pixbuf (GTK_IMAGE (priv->application_details_icon), pixbuf);
 		gtk_widget_set_visible (priv->application_details_icon, TRUE);
 	} else {
 		gtk_widget_set_visible (priv->application_details_icon, FALSE);
@@ -791,16 +791,6 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 
 	addons = gtk_container_get_children (GTK_CONTAINER (priv->list_box_addons));
 	gtk_widget_set_visible (priv->box_addons, addons != NULL);
-	for (l = addons; l; l = l->next) {
-		/* show checkboxes in front of addons if the app isn't yet installed */
-		switch (gs_app_get_state (priv->app)) {
-		case AS_APP_STATE_INSTALLED:
-		case AS_APP_STATE_UPDATABLE:
-			break;
-		default:
-			break;
-		}
-	}
 	g_list_free (addons);
 }
 
@@ -844,6 +834,9 @@ gs_shell_details_refresh_addons (GsShellDetails *shell_details)
 		GtkWidget *row;
 
 	        addon = g_ptr_array_index (addons, i);
+		if (gs_app_get_state (addon) == AS_APP_STATE_UNAVAILABLE)
+			continue;
+
 	        row = gs_app_addon_row_new ();
 
 	        gs_app_addon_row_set_addon (GS_APP_ADDON_ROW (row), addon);
@@ -869,6 +862,7 @@ gs_shell_details_app_refine_cb (GObject *source,
 	GsShellDetails *shell_details = GS_SHELL_DETAILS (user_data);
 	GsShellDetailsPrivate *priv = shell_details->priv;
 	gboolean ret;
+	gchar *app_dump;
 
 	ret = gs_plugin_loader_app_refine_finish (plugin_loader,
 						  res,
@@ -880,6 +874,12 @@ gs_shell_details_app_refine_cb (GObject *source,
 		g_error_free (error);
 		return;
 	}
+
+	/* show some debugging */
+	app_dump = gs_app_to_string (priv->app);
+	g_debug ("%s", app_dump);
+	g_free (app_dump);
+
 	gs_shell_details_refresh_addons (shell_details);
 	gs_shell_details_refresh_all (shell_details);
 	gs_shell_details_set_state (shell_details, GS_SHELL_DETAILS_STATE_READY);
@@ -992,12 +992,6 @@ void
 gs_shell_details_set_app (GsShellDetails *shell_details, GsApp *app)
 {
 	GsShellDetailsPrivate *priv = shell_details->priv;
-	gchar *app_dump;
-
-	/* show some debugging */
-	app_dump = gs_app_to_string (app);
-	g_debug ("%s", app_dump);
-	g_free (app_dump);
 
 	/* get extra details about the app */
 	gs_shell_details_set_state (shell_details, GS_SHELL_DETAILS_STATE_LOADING);
