@@ -142,6 +142,10 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 				     GS_PLUGIN_LOADER_ERROR,
 				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS)) {
 			g_debug ("no sources to show");
+		} else if (g_error_matches (error,
+		                            G_IO_ERROR,
+		                            G_IO_ERROR_CANCELLED)) {
+			g_debug ("get sources cancelled");
 		} else {
 			g_warning ("failed to get sources: %s", error->message);
 		}
@@ -333,7 +337,7 @@ set_plugin_loader (GsSourcesDialog *dialog, GsPluginLoader *plugin_loader)
 }
 
 static void
-gs_sources_dialog_finalize (GObject *object)
+gs_sources_dialog_dispose (GObject *object)
 {
 	GsSourcesDialog *dialog = GS_SOURCES_DIALOG (object);
 	GsSourcesDialogPrivate *priv = gs_sources_dialog_get_instance_private (dialog);
@@ -345,7 +349,7 @@ gs_sources_dialog_finalize (GObject *object)
 		g_clear_object (&priv->cancellable);
 	}
 
-	G_OBJECT_CLASS (gs_sources_dialog_parent_class)->finalize (object);
+	G_OBJECT_CLASS (gs_sources_dialog_parent_class)->dispose (object);
 }
 
 static void
@@ -387,7 +391,7 @@ gs_sources_dialog_class_init (GsSourcesDialogClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	object_class->finalize = gs_sources_dialog_finalize;
+	object_class->dispose = gs_sources_dialog_dispose;
 
 	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/gs-sources-dialog.ui");
 
