@@ -94,7 +94,6 @@ notify_offline_update_available (GsUpdateMonitor *monitor)
 
 	/* rate limit update notifications to once per hour */
 	monitor->reenable_offline_update_id = g_timeout_add_seconds (3600, reenable_offline_update_notification, monitor);
-	g_source_set_name_by_id (monitor->reenable_offline_update_id, "[gnome-software] reenable_offline_update_notification");
 
 	title = _("Software Updates Available");
 	body = _("Important OS and application updates are ready to be installed");
@@ -132,22 +131,24 @@ show_installed_updates_notification (GsUpdateMonitor *monitor)
 {
 	const gchar *message;
 	const gchar *title;
-	gboolean success;
-	guint num_packages = 1;
 	GNotification *notification;
 	GIcon *icon;
+	PkResults *results;
 
-	if (!gs_offline_updates_get_status (&success, &num_packages, NULL, NULL))
+	results = pk_offline_get_results (NULL);
+	if (results == NULL)
 		return;
-
-	if (success) {
+	if (pk_results_get_exit_code (results) == PK_EXIT_ENUM_SUCCESS) {
+		GPtrArray *packages;
+		packages = pk_results_get_package_array (results);
 		title = ngettext ("Software Update Installed",
 				  "Software Updates Installed",
-				  num_packages);
+				  packages->len);
 		/* TRANSLATORS: message when we've done offline updates */
 		message = ngettext ("An important OS update has been installed.",
 				    "Important OS updates have been installed.",
-				    num_packages);
+				    packages->len);
+		g_ptr_array_unref (packages);
 	} else {
 
 		title = _("Software Updates Failed");
@@ -160,7 +161,7 @@ show_installed_updates_notification (GsUpdateMonitor *monitor)
 	icon = g_themed_icon_new ("gnome-software-symbolic");
 	g_notification_set_icon (notification, icon);
 	g_object_unref (icon);
-	if (success)
+	if (pk_results_get_exit_code (results) == PK_EXIT_ENUM_SUCCESS)
 		g_notification_add_button_with_target (notification, _("Review"), "app.set-mode", "s", "updated");
 	else
 		g_notification_add_button (notification, _("Show Details"), "app.show-offline-update-error");
@@ -168,6 +169,7 @@ show_installed_updates_notification (GsUpdateMonitor *monitor)
 
 	g_application_send_notification (monitor->application, "offline-updates", notification);
 	g_object_unref (notification);
+	g_object_unref (results);
 }
 
 static gboolean
@@ -180,7 +182,8 @@ check_offline_update_cb (gpointer user_data)
 	g_settings_get (monitor->settings,
 	                "install-timestamp", "x", &time_last_notified);
 
-	if (gs_offline_updates_get_time_completed (&time_update_completed)) {
+	time_update_completed = pk_offline_get_results_mtime (NULL);
+	if (time_update_completed > 0) {
 		if (time_last_notified < time_update_completed)
 			show_installed_updates_notification (monitor);
 
@@ -490,8 +493,6 @@ start_hourly_checks_cb (gpointer data)
 
 	monitor->check_hourly_id =
 		g_timeout_add_seconds (3600, check_hourly_cb, monitor);
-	g_source_set_name_by_id (monitor->check_hourly_id,
-				 "[gnome-software] check_hourly_cb");
 
 	monitor->start_hourly_checks_id = 0;
 	return G_SOURCE_REMOVE;
@@ -530,8 +531,6 @@ gs_update_monitor_init (GsUpdateMonitor *monitor)
 
 	monitor->check_offline_update_id = 
 		g_timeout_add_seconds (15, check_offline_update_cb, monitor);
-	g_source_set_name_by_id (monitor->check_offline_update_id,
-				 "[gnome-software] check_offline_update_cb");
 
 	monitor->settings = g_settings_new ("org.gnome.software");
 	g_settings_get (monitor->settings, "check-timestamp", "x", &tmp);
@@ -539,8 +538,6 @@ gs_update_monitor_init (GsUpdateMonitor *monitor)
 
 	monitor->start_hourly_checks_id =
 		g_timeout_add_seconds (60, start_hourly_checks_cb, monitor);
-	g_source_set_name_by_id (monitor->start_hourly_checks_id,
-				 "[gnome-software] start_hourly_checks_cb");
 
 	monitor->cancellable = g_cancellable_new ();
 	monitor->task = pk_task_new ();
@@ -603,7 +600,7 @@ gs_update_monitor_class_init (GsUpdateMonitorClass *klass)
 static void
 remove_stale_notifications (GsUpdateMonitor *monitor)
 {
-	if (gs_offline_updates_results_available ()) {
+	if (pk_offline_get_results_mtime (NULL) > 0) {
 		g_debug ("Withdrawing stale notifications");
 
 		g_application_withdraw_notification (monitor->application,
