@@ -80,8 +80,14 @@ gs_stop_spinner (GtkSpinner *spinner)
 void
 gs_start_spinner (GtkSpinner *spinner)
 {
+	gboolean active;
 	guint id;
 
+	/* Don't do anything if it's already spinning */
+	g_object_get (spinner, "active", &active, NULL);
+	if (active || g_object_get_data (G_OBJECT (spinner), "start-timeout") != NULL)
+		return;
+
 	gtk_widget_set_opacity (GTK_WIDGET (spinner), 0);
 	id = g_timeout_add (SPINNER_DELAY, start_spinning, spinner);
 	g_object_set_data_full (G_OBJECT (spinner), "start-timeout",
@@ -353,4 +359,27 @@ gs_reboot (GCallback reboot_failed)
 	g_object_unref (bus);
 }
 
+/**
+ * gs_image_set_from_pixbuf_with_scale:
+ **/
+void
+gs_image_set_from_pixbuf_with_scale (GtkImage *image, const GdkPixbuf *pixbuf, gint scale)
+{
+	cairo_surface_t *surface;
+	surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, scale, NULL);
+	gtk_image_set_from_surface (image, surface);
+	cairo_surface_destroy (surface);
+}
+
+/**
+ * gs_image_set_from_pixbuf:
+ **/
+void
+gs_image_set_from_pixbuf (GtkImage *image, const GdkPixbuf *pixbuf)
+{
+	gint scale;
+	scale = gdk_pixbuf_get_width (pixbuf) / 64;
+	gs_image_set_from_pixbuf_with_scale (image, pixbuf, scale);
+}
+
 /* vim: set noexpandtab: */
