@@ -37,6 +37,7 @@ struct GsPluginPrivate {
 	AsStore			*store;
 	gchar			*locale;
 	gsize			 done_init;
+	gboolean		 has_hi_dpi_support;
 };
 
 static gboolean gs_plugin_refine_item (GsPlugin *plugin, GsApp *app, AsApp *item, GError **error);
@@ -77,6 +78,10 @@ gs_plugin_appstream_store_changed_cb (AsStore *store, GsPlugin *plugin)
 {
 	g_debug ("AppStream metadata changed, reloading cache");
 	plugin->priv->done_init = FALSE;
+
+	/* this is not strictly true, but it causes all the UI to be reloaded
+	 * which is what we really want */
+	gs_plugin_updates_changed (plugin);
 }
 
 /**
@@ -124,11 +129,17 @@ gs_plugin_destroy (GsPlugin *plugin)
  * gs_plugin_startup:
  */
 static gboolean
-gs_plugin_startup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
+gs_plugin_startup (GsPlugin *plugin, GError **error)
 {
 	GPtrArray *items;
 	gboolean ret;
 	gchar *tmp;
+#if AS_CHECK_VERSION(0,3,1)
+	guint i;
+#endif
+
+	/* clear all existing applications if the store was invalidated */
+	as_store_remove_all (plugin->priv->store);
 
 	/* get the locale without the UTF-8 suffix */
 	plugin->priv->locale = g_strdup (setlocale (LC_MESSAGES, NULL));
@@ -148,7 +159,7 @@ gs_plugin_startup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 			     AS_STORE_LOAD_FLAG_APPDATA |
 			     AS_STORE_LOAD_FLAG_DESKTOP |
 			     AS_STORE_LOAD_FLAG_APP_INSTALL,
-			     cancellable,
+			     NULL,
 			     error);
 	if (!ret)
 		goto out;
@@ -162,11 +173,126 @@ gs_plugin_startup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 			     _("No AppStream data found"));
 		goto out;
 	}
+
+	/* look for any application with a HiDPI icon kudo */
+#if AS_CHECK_VERSION(0,3,1)
+	for (i = 0; i < items->len; i++) {
+		AsApp *app;
+		app = g_ptr_array_index (items, i);
+		if (as_app_has_kudo_kind (app, AS_KUDO_KIND_HI_DPI_ICON)) {
+			plugin->priv->has_hi_dpi_support = TRUE;
+			break;
+		}
+	}
+#endif
 out:
 	gs_profile_stop (plugin->profile, "appstream::startup");
 	return ret;
 }
 
+#if AS_CHECK_VERSION(0,3,1)
+
+/**
+ * gs_plugin_refine_item_pixbuf:
+ */
+static void
+gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
+{
+	GError *error = NULL;
+	AsIcon *icon;
+	gboolean ret;
+
+	icon = as_app_get_icon_default (item);
+	switch (as_icon_get_kind (icon)) {
+	case AS_ICON_KIND_REMOTE:
+		gs_app_set_icon (app, as_icon_get_name (icon));
+		break;
+	case AS_ICON_KIND_STOCK:
+		gs_app_set_icon (app, as_icon_get_name (icon));
+		ret = gs_app_load_icon (app, plugin->scale, &error);
+		if (!ret) {
+			g_warning ("failed to load stock icon %s: %s",
+				   as_icon_get_name (icon), error->message);
+			g_error_free (error);
+			return;
+		}
+		break;
+	case AS_ICON_KIND_CACHED:
+		if (plugin->scale == 2)
+			icon = as_app_get_icon_for_size (item, 128, 128);
+		if (icon == NULL)
+			icon = as_app_get_icon_for_size (item, 64, 64);
+		if (icon == NULL) {
+			g_warning ("failed to find cached icon %s",
+				   as_icon_get_name (icon));
+			return;
+		}
+		if (!as_icon_load (icon, AS_ICON_LOAD_FLAG_SEARCH_SIZE, &error)) {
+			g_warning ("failed to load cached icon %s: %s",
+				   as_icon_get_name (icon), error->message);
+			g_error_free (error);
+			return;
+		}
+		gs_app_set_pixbuf (app, as_icon_get_pixbuf (icon));
+		break;
+	default:
+		g_warning ("icon kind unknown for %s", as_app_get_id_full (item));
+		break;
+	}
+}
+
+#else
+
+/**
+ * _as_app_get_icon_for_scale:
+ */
+static GdkPixbuf *
+_as_app_get_icon_for_scale (AsApp *app, gint scale, GError **error)
+{
+	GdkPixbuf *pixbuf = NULL;
+	const gchar *icon;
+	const gchar *icon_path;
+	gchar *filename_hidpi = NULL;
+	gchar *filename_lodpi = NULL;
+	gchar *filename = NULL;
+
+	/* HiDPI */
+	icon = as_app_get_icon (app);
+	if (icon == NULL)
+		goto out;
+	icon_path = as_app_get_icon_path (app);
+	if (icon_path == NULL)
+		goto out;
+	if (scale == 2) {
+		filename_hidpi = g_build_filename (icon_path, "128x128", icon, NULL);
+		if (g_file_test (filename_hidpi, G_FILE_TEST_EXISTS)) {
+			pixbuf = gdk_pixbuf_new_from_file (filename_hidpi, error);
+			if (pixbuf == NULL)
+				goto out;
+			goto out;
+		}
+	}
+
+	/* LoDPI */
+	filename_lodpi = g_build_filename (icon_path, "64x64", icon, NULL);
+	if (g_file_test (filename_lodpi, G_FILE_TEST_EXISTS)) {
+		pixbuf = gdk_pixbuf_new_from_file (filename_lodpi, error);
+		goto out;
+	}
+
+	/* fallback */
+	filename = g_build_filename (icon_path, icon, NULL);
+	pixbuf = gdk_pixbuf_new_from_file_at_scale (filename, 64, 64,
+						    FALSE, error);
+	if (pixbuf == NULL)
+		goto out;
+out:
+	g_free (filename_hidpi);
+	g_free (filename_lodpi);
+	g_free (filename);
+	return pixbuf;
+}
+
 /**
  * gs_plugin_refine_item_pixbuf:
  */
@@ -177,7 +303,6 @@ gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
 	GError *error = NULL;
 	const gchar *icon;
 	gboolean ret;
-	gchar *full_filename = NULL;
 
 	icon = as_app_get_icon (item);
 	switch (as_app_get_icon_kind (item)) {
@@ -186,7 +311,7 @@ gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
 		break;
 	case AS_ICON_KIND_STOCK:
 		gs_app_set_icon (app, icon);
-		ret = gs_app_load_icon (app, &error);
+		ret = gs_app_load_icon (app, plugin->scale, &error);
 		if (!ret) {
 			g_warning ("failed to load stock icon %s: %s",
 				   icon, error->message);
@@ -195,11 +320,10 @@ gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
 		}
 		break;
 	case AS_ICON_KIND_CACHED:
-		full_filename = g_build_filename (as_app_get_icon_path (item), icon, NULL);
-		pb = gdk_pixbuf_new_from_file (full_filename, &error);
+		pb = _as_app_get_icon_for_scale (item, plugin->scale, &error);
 		if (pb == NULL) {
 			g_warning ("failed to load cached icon %s: %s",
-				   full_filename, error->message);
+				   as_app_get_icon (item), error->message);
 			g_error_free (error);
 			goto out;
 		}
@@ -212,8 +336,8 @@ gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
 out:
 	if (pb != NULL)
 		g_object_unref (pb);
-	g_free (full_filename);
 }
+#endif
 
 /**
  * gs_plugin_refine_add_addons:
@@ -241,10 +365,12 @@ gs_plugin_refine_add_addons (GsPlugin *plugin, GsApp *app, AsApp *item)
 		if (!ret) {
 			g_warning ("failed to refine addon: %s", error->message);
 			g_error_free (error);
+			g_object_unref (addon);
 			continue;
 		}
 
 		gs_app_add_addon (app, addon);
+		g_object_unref (addon);
 	}
 }
 /**
@@ -525,8 +651,13 @@ gs_plugin_refine_item (GsPlugin *plugin,
 	}
 
 	/* set icon */
+#if AS_CHECK_VERSION(0,3,1)
+	if (as_app_get_icon_default (item) != NULL && gs_app_get_pixbuf (app) == NULL)
+		gs_plugin_refine_item_pixbuf (plugin, app, item);
+#else
 	if (as_app_get_icon (item) != NULL && gs_app_get_pixbuf (app) == NULL)
 		gs_plugin_refine_item_pixbuf (plugin, app, item);
+#endif
 
 	/* set categories */
 	if (as_app_get_categories (item) != NULL &&
@@ -703,7 +834,7 @@ gs_plugin_refine (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -713,23 +844,19 @@ gs_plugin_refine (GsPlugin *plugin,
 	for (l = *list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		ret = gs_plugin_refine_from_id (plugin, app, &found, error);
-		if (!ret) {
-			gs_profile_stop (plugin->profile, "appstream::refine");
+		if (!ret)
 			goto out;
-		}
 		if (!found) {
 			ret = gs_plugin_refine_from_pkgname (plugin, app, error);
-			if (!ret) {
-				gs_profile_stop (plugin->profile, "appstream::refine");
+			if (!ret)
 				goto out;
-			}
 		}
 	}
-	gs_profile_stop (plugin->profile, "appstream::refine");
 
 	/* sucess */
 	ret = TRUE;
 out:
+	gs_profile_stop (plugin->profile, "appstream::refine");
 	return ret;
 }
 
@@ -754,7 +881,7 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -792,8 +919,8 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		gs_plugin_add_app (list, app);
 		g_object_unref (app);
 	}
-	gs_profile_stop (plugin->profile, "appstream::add-category-apps");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add-category-apps");
 	return ret;
 }
 
@@ -827,6 +954,7 @@ gs_plugin_add_search_item (GsPlugin *plugin,
 			   GList **list,
 			   AsApp *app,
 			   gchar **values,
+			   GCancellable *cancellable,
 			   GError **error)
 {
 	AsApp *item;
@@ -854,6 +982,9 @@ gs_plugin_add_search_item (GsPlugin *plugin,
 
 	/* add the thing that we extend, not the addon itself */
 	for (i = 0; i < extends->len; i++) {
+		if (g_cancellable_set_error_if_cancelled (cancellable, error))
+			goto out;
+
 		id = g_ptr_array_index (extends, i);
 		item = as_store_get_app_by_id (plugin->priv->store, id);
 		if (item == NULL)
@@ -887,7 +1018,7 @@ gs_plugin_add_search (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -897,13 +1028,16 @@ gs_plugin_add_search (GsPlugin *plugin,
 	gs_profile_start (plugin->profile, "appstream::search");
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
+		if (g_cancellable_set_error_if_cancelled (cancellable, error))
+			goto out;
+
 		item = g_ptr_array_index (array, i);
-		ret = gs_plugin_add_search_item (plugin, list, item, values, error);
+		ret = gs_plugin_add_search_item (plugin, list, item, values, cancellable, error);
 		if (!ret)
 			goto out;
 	}
-	gs_profile_stop (plugin->profile, "appstream::search");
 out:
+	gs_profile_stop (plugin->profile, "appstream::search");
 	return ret;
 }
 
@@ -924,7 +1058,7 @@ gs_plugin_add_installed (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -944,8 +1078,8 @@ gs_plugin_add_installed (GsPlugin *plugin,
 			g_object_unref (app);
 		}
 	}
-	gs_profile_stop (plugin->profile, "appstream::add_installed");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add_installed");
 	return ret;
 }
 
@@ -1011,7 +1145,7 @@ gs_plugin_add_categories (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -1028,8 +1162,8 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			continue;
 		gs_plugin_add_categories_for_app (*list, app);
 	}
-	gs_profile_stop (plugin->profile, "appstream::add-categories");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add-categories");
 	return ret;
 }
 
@@ -1082,6 +1216,11 @@ gs_plugin_add_popular_from_category (GsPlugin *plugin,
 			continue;
 		if (category_exclude != NULL && as_app_has_category (item, category_exclude))
 			continue;
+#if AS_CHECK_VERSION(0,3,1)
+		if (plugin->priv->has_hi_dpi_support &&
+		    !as_app_has_kudo_kind (item, AS_KUDO_KIND_HI_DPI_ICON))
+			continue;
+#endif
 
 		/* add application */
 		app = gs_app_new (as_app_get_id_full (item));
@@ -1177,8 +1316,8 @@ gs_plugin_add_popular_by_cat (GsPlugin *plugin,
 		}
 
 	}
-	gs_profile_stop (plugin->profile, "appstream::add_popular[cat]");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add_popular[cat]");
 	if (ignore_cats != NULL)
 		g_hash_table_unref (ignore_cats);
 	return ret;
@@ -1251,8 +1390,8 @@ gs_plugin_add_popular_by_source (GsPlugin *plugin,
 		}
 		g_object_unref (app);
 	}
-	gs_profile_stop (plugin->profile, "appstream::add_popular[source]");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add_popular[source]");
 	if (installed != NULL)
 		g_hash_table_unref (installed);
 	return ret;
@@ -1277,7 +1416,7 @@ gs_plugin_add_popular (GsPlugin *plugin,
 
 	/* load XML files */
 	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, cancellable, error);
+		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
 			goto out;
@@ -1322,8 +1461,8 @@ gs_plugin_add_popular (GsPlugin *plugin,
 			goto out;
 	}
 
-	gs_profile_stop (plugin->profile, "appstream::add_popular");
 out:
+	gs_profile_stop (plugin->profile, "appstream::add_popular");
 	if (ignore_apps != NULL)
 		g_hash_table_unref (ignore_apps);
 	return ret;
