@@ -155,7 +155,7 @@ gs_plugin_add_installed_file (GsPlugin *plugin,
 	gs_app_set_id_kind (*app, AS_ID_KIND_WEB_APP);
 	gs_app_add_source_id (*app, path);
 	gs_app_set_icon (*app, icon);
-	ret = gs_app_load_icon (*app, error);
+	ret = gs_app_load_icon (*app, plugin->scale, error);
 	if (!ret)
 		goto out;
 out:
@@ -297,6 +297,9 @@ gs_plugin_add_search (GsPlugin *plugin,
 
 	/* add any matching apps */
 	for (l = plugin->priv->list; l != NULL; l = l->next) {
+		if (g_cancellable_set_error_if_cancelled (cancellable, error))
+			goto out;
+
 		app = GS_APP (l->data);
 		if (gs_plugin_epiphany_match_app (app, values))
 			gs_plugin_add_app (list, app);
@@ -496,6 +499,7 @@ gs_plugin_write_file (GsApp *app, const gchar *filename, GError **error)
 	if (!ret)
 		goto out;
 out:
+	g_free (data);
 	g_free (profile);
 	g_free (exec);
 	g_free (wmclass);
@@ -648,7 +652,7 @@ gs_plugin_refine_app (GsPlugin *plugin, GsApp *app, GError **error)
 
 	/* set local icon name */
 	gs_app_set_icon (app, filename_icon);
-	ret = gs_app_load_icon (app, error);
+	ret = gs_app_load_icon (app, plugin->scale, error);
 	if (!ret)
 		goto out;
 
